/*
    pinco - a didactic framework for Web development
    Copyright (C) 2002-2003  Giansalvatore Mecca - mecca@unibas.it
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ----
    pinco - un framework didattico per lo sviluppo Web
    Copyright (C) 2002-2003  Giansalvatore Mecca - mecca@unibas.it
 
    Questo  programma   software  libero;   lecito redistribuirlo  o
    modificarlo secondo i termini  della Licenza Pubblica Generica GNU
    come  pubblicata dalla Free  Software Foundation; o la versione 2
    della licenza o (a propria scelta) una versione successiva.
 
    Questo programma   distribuito nella  speranza che sia  utile, ma
    SENZA  ALCUNA GARANZIA;  senza  neppure la  garanzia implicita  di
    NEGOZIABILIT  o di  APPLICABILIT PER  UN PARTICOLARE  SCOPO.  Si
    veda la Licenza Pubblica Generica GNU per avere maggiori dettagli.
 
    Questo  programma deve  essere  distribuito assieme  ad una  copia
    della Licenza Pubblica Generica GNU;  in caso contrario, se ne pu
    ottenere  una scrivendo  alla Free  Software Foundation,  Inc., 59
    Temple Place, Suite 330, Boston, MA 02111-1307 USA
 
 */

package it.unibas.pinco.utilita;

public class Convalidatore {
    
    public static void verificaIntero(String stringa, String nomeValore, java.util.List listaErrori) {
        try {
            int valore = Integer.parseInt(stringa);
        } catch (NumberFormatException nfe) {
            String errore = "Errore nel valore del dato \"" + nomeValore + "\"\n" +
                    "Non si tratta di un numero\n";
            listaErrori.add(errore);
        }
    }
    
    public static void verificaInteroMinimo(String stringa, int minimo, String nomeValore, java.util.List listaErrori) {
        verificaIntero(stringa, nomeValore, listaErrori);
        try {
            int valore = Integer.parseInt(stringa);
            if (valore < minimo) {
                String errore = "Errore nel valore del dato \"" + nomeValore + "\"\n" +
                        "deve essere maggiore o uguale a " + minimo + "\n";
                listaErrori.add(errore);
            }
        } catch (Exception e) {}
    }
    
    public static void verificaInteroMassimo(String stringa, int massimo, String nomeValore, java.util.List listaErrori) {
        verificaIntero(stringa, nomeValore, listaErrori);
        try {
            int valore = Integer.parseInt(stringa);
            if (valore > massimo) {
                String errore = "Errore nel valore del dato \"" + nomeValore + "\"\n" +
                        "deve essere minore di " + massimo + "\n";
                listaErrori.add(errore);
            }
        } catch (Exception e) {}
    }
    
    public static void verificaInteroIntervallo(String stringa, int minimo, int massimo,
            String nomeValore, java.util.List listaErrori) {
        verificaIntero(stringa, nomeValore, listaErrori);
        try {
            int valore = Integer.parseInt(stringa);
            if (valore < minimo || valore > massimo) {
                String errore = "Errore nel valore del dato \"" + nomeValore + "\"\n" +
                        "deve essere compreso tra " + minimo + " e " + massimo + "\n";
                listaErrori.add(errore);
            }
        } catch (Exception e) {}
    }
    
    public static void verificaReale(String stringa, String nomeValore, java.util.List listaErrori) {
        try {
            double valore = Double.parseDouble(stringa);
        } catch (NumberFormatException nfe) {
            String errore = "Errore nel valore del dato \"" + nomeValore + "\"\n" +
                    "Non si tratta di un numero\n";
            listaErrori.add(errore);
        }
    }
        
    public static void verificaRealeMinimo(String stringa, double minimo, String nomeValore, java.util.List listaErrori) {
        verificaReale(stringa, nomeValore, listaErrori);
        try {
            double valore = Double.parseDouble(stringa);
            if (valore < minimo) {
                String errore = "Errore nel valore del dato \"" + nomeValore + "\"\n" +
                        "deve essere maggiore o uguale a " + minimo + "\n";
                listaErrori.add(errore);
            }
        } catch (Exception e) {}
    }

    public static void verificaRealeMassimo(String stringa, double massimo, String nomeValore, java.util.List listaErrori) {
        verificaReale(stringa, nomeValore, listaErrori);
        try {
            double valore = Double.parseDouble(stringa);
            if (valore > massimo) {
                String errore = "Errore nel valore del dato \"" + nomeValore + "\"\n" +
                        "deve essere minore o uguale a " + massimo + "\n";
                listaErrori.add(errore);
            }
        } catch (Exception e) {}
    }

    public static void verificaRealeIntervallo(String stringa, double minimo, double massimo, 
                                               String nomeValore, java.util.List listaErrori) {
        verificaReale(stringa, nomeValore, listaErrori);
        try {
            double valore = Double.parseDouble(stringa);
            if (valore < minimo || valore > massimo) {
                String errore = "Errore nel valore del dato \"" + nomeValore + "\"\n" +
                        "deve essere compreso tra " + minimo + " e " + massimo + "\n";
                listaErrori.add(errore);
            }
        } catch (Exception e) {}
    }
            
    public static void verificaStringaNonNulla(String stringa, String nomeValore, java.util.List listaErrori) {
        if (stringa == null || stringa.equals("")) {
            String errore = "Errore nel valore del dato \"" + nomeValore + "\"\n" +
                             "il valore non pu essere nullo\n";
            listaErrori.add(errore);
        }
    }

    public static void verificaLunghezzaStringa(String stringa, int lunghezza, 
                                                String nomeValore, java.util.List listaErrori) {
        if (stringa != null && stringa.length() != lunghezza) {
            String errore = "Errore nel valore del dato \"" + nomeValore + "\"\n" +
                             "la lunghezza deve essere esattamente " + lunghezza + " caratteri\n";
            listaErrori.add(errore);
        }
    }

}