/*
    pinco - a didactic framework for Web development
    Copyright (C) 2002-2003  Giansalvatore Mecca - mecca@unibas.it
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ----
    pinco - un framework didattico per lo sviluppo Web
    Copyright (C) 2002-2003  Giansalvatore Mecca - mecca@unibas.it
 
    Questo  programma   software  libero;   lecito redistribuirlo  o
    modificarlo secondo i termini  della Licenza Pubblica Generica GNU
    come  pubblicata dalla Free  Software Foundation; o la versione 2
    della licenza o (a propria scelta) una versione successiva.
 
    Questo programma   distribuito nella  speranza che sia  utile, ma
    SENZA  ALCUNA GARANZIA;  senza  neppure la  garanzia implicita  di
    NEGOZIABILIT  o di  APPLICABILIT PER  UN PARTICOLARE  SCOPO.  Si
    veda la Licenza Pubblica Generica GNU per avere maggiori dettagli.
 
    Questo  programma deve  essere  distribuito assieme  ad una  copia
    della Licenza Pubblica Generica GNU;  in caso contrario, se ne pu
    ottenere  una scrivendo  alla Free  Software Foundation,  Inc., 59
    Temple Place, Suite 330, Boston, MA 02111-1307 USA
 
 */

package it.unibas.pinco.utilita;

import java.io.InputStream;
import java.io.FileInputStream;
import java.util.Properties;
import it.unibas.pinco.framework.Applicazione;

public class Logger {
    
    private static final String NOMEFILE = "/risorse/logger.properties";
    private java.util.logging.Logger logger;
    
    public Logger(String nome) {
        this.logger = java.util.logging.Logger.getLogger(nome);
        inizializza();
    }
    
    private void inizializza() {
        Properties proprieta = caricaProperties();
        java.util.logging.Level livello = selezionaLivello(proprieta);
        java.util.logging.Handler handler = selezionaHandler(proprieta);
        logger.setUseParentHandlers(false);
        logger.addHandler(handler);
        logger.setLevel(livello);
        handler.setLevel(livello);
    }
    
    private Properties caricaProperties() {
        InputStream stream = null;
        try {
            Properties proprieta = new Properties();
            stream = ResourceManager.getStream(this.NOMEFILE);
            proprieta.load(stream);
            System.out.println(proprieta);
            return proprieta;
        } catch (Exception e) {
            System.err.println("Impossibile caricare il file logger.properties");
            return null;
        } finally {
            if (stream != null) {
                try { stream.close(); } catch (Exception e) {}
            }
        }
    }
    
    private java.util.logging.Level selezionaLivello(Properties proprieta) {
        if (proprieta != null) {
            String livello = proprieta.getProperty("it.unibas.pinco.logLevel");
            if (livello != null && !livello.equals("")) {
                System.out.println("Livello di logging: " + livello);
                if (livello.equalsIgnoreCase("finer")) {
                    return java.util.logging.Level.FINER;
                } else if (livello.equalsIgnoreCase("fine")) {
                    return java.util.logging.Level.FINE;
                } else if (livello.equalsIgnoreCase("severe")) {
                    return java.util.logging.Level.SEVERE;
                } else if (livello.equalsIgnoreCase("off")) {
                    return java.util.logging.Level.OFF;
                } else if (livello.equalsIgnoreCase("all")) {
                    return java.util.logging.Level.ALL;
                }
            }
        }
        return java.util.logging.Level.INFO;
    }
    
    private java.util.logging.Handler selezionaHandler(Properties proprieta){
        if (proprieta != null) {
            String nomeFile = proprieta.getProperty("it.unibas.pinco.logFile");
            if (nomeFile != null && !nomeFile.equals("")) {
                System.out.println("File di logging: " + nomeFile);
                try {
                    java.util.logging.FileHandler fileHandler = new java.util.logging.FileHandler(nomeFile);
                    fileHandler.setFormatter(new java.util.logging.SimpleFormatter());
                    return fileHandler;
                } catch (java.io.IOException ioe) {
                    System.err.println("Impossibile utilizzare il file di log specificato");
                }
            }
        }
        java.util.logging.ConsoleHandler consoleHandler = new java.util.logging.ConsoleHandler();
        return consoleHandler;
    }
    
    public java.util.logging.Level getLevel() {
        return logger.getLevel();
    }
    
    public void setLevel(java.util.logging.Level livello) {
        logger.setLevel(livello);
        java.util.logging.Handler[] handlers = logger.getHandlers();
        for (int i = 0; i < handlers.length; i++) {
            handlers[i].setLevel(livello);
        }
    }
    
    public void logFiner(String messaggio) {
        logger.logp(java.util.logging.Level.FINER, "", "", messaggio);
    }
    
    public void logFiner(String classe, String metodo, String messaggio) {
        logger.logp(java.util.logging.Level.FINER, classe, metodo, messaggio);
    }
    
    public void logFine(String messaggio) {
        logger.logp(java.util.logging.Level.FINE, "", "", messaggio);
    }
    
    public void logFine(String classe, String metodo, String messaggio) {
        logger.logp(java.util.logging.Level.FINE, classe, metodo, messaggio);
    }
    
    public void logInfo(String messaggio) {
        logger.logp(java.util.logging.Level.INFO, "", "", messaggio);
    }
    
    public void logInfo(String classe, String metodo, String messaggio) {
        logger.logp(java.util.logging.Level.INFO, classe, metodo, messaggio);
    }
    
    public void logSevere(String messaggio) {
        logger.logp(java.util.logging.Level.SEVERE, "", "", messaggio);
    }
    
    public void logSevere(String classe, String metodo, String messaggio) {
        logger.logp(java.util.logging.Level.SEVERE, classe, metodo, messaggio);
    }
    
}

