/*
    pinco - a didactic framework for Web development
    Copyright (C) 2002-2003  Giansalvatore Mecca - mecca@unibas.it
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ----
    pinco - un framework didattico per lo sviluppo Web
    Copyright (C) 2002-2003  Giansalvatore Mecca - mecca@unibas.it
 
    Questo  programma   software  libero;   lecito redistribuirlo  o
    modificarlo secondo i termini  della Licenza Pubblica Generica GNU
    come  pubblicata dalla Free  Software Foundation; o la versione 2
    della licenza o (a propria scelta) una versione successiva.
 
    Questo programma   distribuito nella  speranza che sia  utile, ma
    SENZA  ALCUNA GARANZIA;  senza  neppure la  garanzia implicita  di
    NEGOZIABILIT  o di  APPLICABILIT PER  UN PARTICOLARE  SCOPO.  Si
    veda la Licenza Pubblica Generica GNU per avere maggiori dettagli.
 
    Questo  programma deve  essere  distribuito assieme  ad una  copia
    della Licenza Pubblica Generica GNU;  in caso contrario, se ne pu
    ottenere  una scrivendo  alla Free  Software Foundation,  Inc., 59
    Temple Place, Suite 330, Boston, MA 02111-1307 USA
 
 */

package it.unibas.pinco.utilita;

import it.unibas.pinco.framework.Applicazione;
import java.io.IOException;
import java.io.InputStream;
import java.net.URI;
import java.net.URISyntaxException;
import java.net.URL;
import java.util.Properties;

public class ResourceManager {
    
    private final static String nomeFileVersione = "/risorse/pinco-version.properties";
    
    public static InputStream getStream(String nomeRisorsa) {
        InputStream stream = ResourceManager.class.getResourceAsStream(nomeRisorsa);
        return stream;
    }
    
    public static URI getURI(String nomeRisorsa) {
        URL url = ResourceManager.class.getResource(nomeRisorsa);
        URI uri = null;
        try {
            uri = url.toURI();
        } catch (URISyntaxException e) {
            Applicazione.logSevere("ResourceManager", "getURI", e.toString());
        }
        return uri;
    }
    
    public static String caricaVersione() {
        Properties proprietaVersione = new Properties();
        InputStream stream = null;
        try {
            stream = getStream(nomeFileVersione);
            proprietaVersione.load(stream);
            String majorVersion = proprietaVersione.getProperty("major.version");
            String minorVersion = proprietaVersione.getProperty("minor.version");
            String buildNumber = proprietaVersione.getProperty("build.number");
            if (majorVersion != null && minorVersion != null && buildNumber != null) {
                return majorVersion + "." + minorVersion + " - build " + buildNumber;
            }
        } catch (IOException e) {
            Applicazione.logSevere("ResourceManager", "caricaVersione", "Impossibile caricare il file della versione " + e);
        } finally {
            if (stream != null) {
                try { stream.close(); } catch (Exception e) {}
            }
        }
        return "(versione non disponibile)";    
    }
}
