/*
    pinco - a didactic framework for Web development
    Copyright (C) 2002-2003  Giansalvatore Mecca - mecca@unibas.it
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ----
    pinco - un framework didattico per lo sviluppo Web
    Copyright (C) 2002-2003  Giansalvatore Mecca - mecca@unibas.it
 
    Questo  programma   software  libero;   lecito redistribuirlo  o
    modificarlo secondo i termini  della Licenza Pubblica Generica GNU
    come  pubblicata dalla Free  Software Foundation; o la versione 2
    della licenza o (a propria scelta) una versione successiva.
 
    Questo programma   distribuito nella  speranza che sia  utile, ma
    SENZA  ALCUNA GARANZIA;  senza  neppure la  garanzia implicita  di
    NEGOZIABILIT  o di  APPLICABILIT PER  UN PARTICOLARE  SCOPO.  Si
    veda la Licenza Pubblica Generica GNU per avere maggiori dettagli.
 
    Questo  programma deve  essere  distribuito assieme  ad una  copia
    della Licenza Pubblica Generica GNU;  in caso contrario, se ne pu
    ottenere  una scrivendo  alla Free  Software Foundation,  Inc., 59
    Temple Place, Suite 330, Boston, MA 02111-1307 USA
 
 */

package it.unibas.pinco.xml;

import it.unibas.pinco.configurazione.DescrittoreAzione;
import it.unibas.pinco.configurazione.Configurazione;
import it.unibas.pinco.framework.Applicazione;
import it.unibas.pinco.framework.PincoException;
import it.unibas.pinco.utilita.ResourceManager;
import java.io.IOException;
import java.net.URI;
import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.parsers.ParserConfigurationException;
import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.NodeList;
import org.xml.sax.SAXException;

public class DAOConfigurazione {
    
    private DAOConfigurazione() {}
    
    private static DAOConfigurazione singleton = new DAOConfigurazione();
    
    public static DAOConfigurazione getInstance() {
        return singleton;
    }
    
    public Configurazione carica(String nomeFile) throws PincoException {
        Configurazione configurazione = new Configurazione();
        Document document = null;
        try {
            document = creaDocument(nomeFile);
            caricaAzioneIniziale(document, configurazione);
            caricaAzioneFinale(document, configurazione);
            caricaAzioni(document, configurazione);
        } catch (Exception e) {
            Applicazione.getPincoLogger().logSevere("DAOConfigurazione", "carica", e + "");
            throw new PincoException(e);
        }
        return configurazione;
    }
        
    private Document creaDocument(String nomeFile) throws PincoException {
        Document document = null;
        try {
            DocumentBuilderFactory factory = DocumentBuilderFactory.newInstance();
            factory.setValidating(true);
            DocumentBuilder builder = factory.newDocumentBuilder();
            ErrorHandler errorHandler = new ErrorHandler();
            builder.setErrorHandler(errorHandler);
            Applicazione.getPincoLogger().logFiner("DAOConfigurazione", "creaDocument", "nomeFile: " + nomeFile);
            //URI uri = ResourceManager.getURI(nomeFile);
            //Applicazione.getPincoLogger().logInfo("DAOConfigurazione", "creaDocument", "uri: " + uri);
            //document = builder.parse(uri.toString());
            document = builder.parse(nomeFile);
            if (!errorHandler.isValido()) {
                throw new PincoException("Il file " + nomeFile + " non e' valido\n" + errorHandler.getErrori());
            }
        } catch (NullPointerException e) {
            throw new PincoException("Impossibile caricare il file " + nomeFile + " " + e);
        } catch (ParserConfigurationException e) {
            throw new PincoException("Errori nel caricamento del file " + nomeFile + " " + e);
        } catch (SAXException e) {
            throw new PincoException("Errori nel caricamento del file " + nomeFile + " " + e);
        } catch (IOException e) {
            throw new PincoException("Errori nel caricamento del file " + nomeFile + " " + e);            
        }
        return document;
    }
    
    private void caricaAzioneIniziale(Document document, Configurazione configurazione) {
        Element root = document.getDocumentElement();
        NodeList listaNodiAzioneIniziale = root.getElementsByTagName("azioneIniziale");
        if (listaNodiAzioneIniziale.getLength() != 0) {
            Element elementoAzioneIniziale = (Element)listaNodiAzioneIniziale.item(0);
            configurazione.setAzioneIniziale(elementoAzioneIniziale.getFirstChild().getNodeValue());
        }
    }
    
    private void caricaAzioneFinale(Document document, Configurazione configurazione) {
        Element root = document.getDocumentElement();
        NodeList listaNodiAzioneFinale = root.getElementsByTagName("azioneFinale");
        if (listaNodiAzioneFinale.getLength() != 0) {
            Element elementoAzioneFinale = (Element)listaNodiAzioneFinale.item(0);
            configurazione.setAzioneFinale(elementoAzioneFinale.getFirstChild().getNodeValue());
        }
    }
    
    private void caricaAzioni(Document document, Configurazione configurazione) {
        Element root = document.getDocumentElement();
        NodeList listaAzioni = root.getElementsByTagName("azioni");
        Element elementoAzioni = (Element)listaAzioni.item(0);
        NodeList listaDescrittori = elementoAzioni.getElementsByTagName("descrittoreAzione");
        for(int i = 0; i < listaDescrittori.getLength(); i++){
            Element elementoDescrittore = (Element)listaDescrittori.item(i);
            DescrittoreAzione descrittoreAzione = new DescrittoreAzione();
            String nomeComando = elementoDescrittore.getAttribute("comando");
            descrittoreAzione.setComando(nomeComando);
            String nomeAzione = elementoDescrittore.getAttribute("azione");
            descrittoreAzione.setAzione(nomeAzione);
            caricaSchermi(elementoDescrittore, descrittoreAzione);
            configurazione.aggiungiDescrittoreAzione(descrittoreAzione);
        }
    }
    
    private void caricaSchermi(Element elementoDescrittore, DescrittoreAzione descrittoreAzione) {
        NodeList listaSchermi = elementoDescrittore.getElementsByTagName("schermoSuccessivo");
        for (int i = 0; i < listaSchermi.getLength(); i++) {
            Element elementoSchermo = (Element)listaSchermi.item(i);
            String esito = elementoSchermo.getAttribute("esito");
            String nomeSchermo = elementoSchermo.getFirstChild().getNodeValue();
            descrittoreAzione.addSchermoSuccessivo(esito, nomeSchermo);
        }
    }
    
    
}
